@@ -26,24 +26,16 @@ class ProgramTrackActionResponse(Node):
     def response(self):
         return self._data['response']
 
-    def set_feedback(self, title: str, message: str):
-        new_block = {
-            'type': 'text',
-            'content': message
-        }
-        new_blocks = [new_block]
-        new_action = {
-            'type': 'blocks',
-            'blocks': new_blocks
-        }
-        new_step = {
-            'name': title,
-            'action': new_action
-        }
-        new_steps = [new_step]
+    def set_feedback(self, title: str, blocks):
         data = {
             'type': 'multiStep',
-            'steps': new_steps
+            'steps': [{
+                'name': title,
+                'action': {
+                    'type': 'blocks',
+                    'blocks': blocks
+                }
+            }]
         }
 
         pma = self._context.client.create_program_track_action(data)
