@@ -6,6 +6,7 @@ from obschart.api.context import Context
 from typing import Optional, Dict, Any, Callable
 import polling
 import datetime
+from .blocks_action_builder import BlocksActionBuilder
 
 OnResponseCallback = Callable[[ProgramTrackActionResponse], None]
 
@@ -232,3 +233,6 @@ class ObschartClient:
         result = self._context.client._execute_mutation(query, input)
 
         return ProgramTrackActionResponse(result['updateProgramTrackActionResponse']['programTrackActionResponse'], self._execute)
+
+    def build_feedback_data(self):
+        return BlocksActionBuilder()
